@@ -1,29 +1,31 @@
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Admin/Makefile.pm $ $Author: ingy $
+# $Revision: #8 $ $Change: 1529 $ $DateTime: 2003/05/19 21:06:26 $ vim: expandtab shiftwidth=4
+
 package Module::Install::Admin::Makefile;
+use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.66_02';
+$VERSION = '0.01';
 
 use strict 'vars';
+use vars '$VERSION';
 
 use ExtUtils::MakeMaker ();
 
 sub postamble {
     my ($self, $text) = @_;
-    my $class       = ref($self);
-    my $top_class   = ref($self->_top);
+    my $class = ref($self);
+    my $top_class = ref($self->_top);
     my $admin_class = join('::', @{$self->_top}{qw(name dispatch)});
 
-    $self->{postamble} ||= << "END_MAKEFILE";
+    $self->{postamble} ||= << "END";
 # --- $class section:
 
 realclean purge ::
 \t\$(RM_F) \$(DISTVNAME).tar\$(SUFFIX)
 \t\$(RM_RF) inc MANIFEST.bak _build
-\t\$(PERL) -I. "-M$admin_class" -e "remove_meta()"
+\t\$(PERL) -I. -M$admin_class -e \"remove_meta()\"
 
-reset :: purge
+reset  :: purge
 
 upload :: test dist
 \tcpan-upload -verbose \$(DISTVNAME).tar\$(SUFFIX)
@@ -34,20 +36,15 @@ grok ::
 distsign ::
 \tcpansign -s
 
-END_MAKEFILE
-
+END
     $self->{postamble} .= $text if defined $text;
-
-    return $self->{postamble};
+    $self->{postamble};
 }
 
 sub preop {
     my $self = shift;
-    my ($user_preop) = @_;
     my $admin_class = join('::', @{$self->_top}{qw(name dispatch)});
-    $user_preop = qq{\$(PERL) -I. "-M$admin_class" -e "dist_preop(q(\$(DISTVNAME)))"} unless $user_preop;
-
-    return { PREOP => $user_preop }
+    +{ PREOP => qq{\$(PERL) -I. -M$admin_class -e "dist_preop(q(\$(DISTVNAME)))"} }
 }
 
 1;
