@@ -1,18 +1,8 @@
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Base.pm $ $Author: autrijus $
+# $Revision: #8 $ $Change: 1375 $ $DateTime: 2003/03/18 12:29:32 $ vim: expandtab shiftwidth=4
+
 package Module::Install::Base;
 
-$VERSION = '0.66_02';
-
-# Suspend handler for "redefined" warnings
-BEGIN {
-	my $w = $SIG{__WARN__};
-	$SIG{__WARN__} = sub { $w };
-}
-
-### This is the ONLY module that shouldn't have strict on
-# use strict;
-
-=pod
-
 =head1 NAME
 
 Module::Install::Base - Base class for Module::Install extensions
@@ -21,8 +11,7 @@ Module::Install::Base - Base class for Module::Install extensions
 
 In a B<Module::Install> extension:
 
-    use Module::Install::Base;
-    @ISA = qw(Module::Install::Base);
+    use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
 =head1 DESCRIPTION
 
@@ -43,17 +32,15 @@ Constructor -- need to preserve at least _top
 sub new {
     my ($class, %args) = @_;
 
-    foreach my $method ( qw(call load) ) {
+    foreach my $method (qw(call load)) {
         *{"$class\::$method"} = sub {
-            shift()->_top->$method(@_);
+            +shift->_top->$method(@_);
         } unless defined &{"$class\::$method"};
     }
 
-    bless( \%args, $class );
+    bless(\%args, $class);
 }
 
-=pod
-
 =item AUTOLOAD
 
 The main dispatcher - copy extensions if missing
@@ -62,13 +49,9 @@ The main dispatcher - copy extensions if missing
 
 sub AUTOLOAD {
     my $self = shift;
-    local $@;
-    my $autoload = eval { $self->_top->autoload } or return;
-    goto &$autoload;
+    goto &{$self->_top->autoload};
 }
 
-=pod
-
 =item _top()
 
 Returns the top-level B<Module::Install> object.
@@ -77,8 +60,6 @@ Returns the top-level B<Module::Install> object.
 
 sub _top { $_[0]->{_top} }
 
-=pod
-
 =item admin()
 
 Returns the C<_top> object's associated B<Module::Install::Admin> object
@@ -89,11 +70,8 @@ with an empty C<AUTOLOAD> method that does nothing at all.
 =cut
 
 sub admin {
-    $_[0]->_top->{admin} or Module::Install::Base::FakeAdmin->new;
-}
-
-sub is_admin {
-    $_[0]->admin->VERSION;
+    my $self = shift;
+    $self->_top->{admin} or Module::Install::Base::FakeAdmin->new;
 }
 
 sub DESTROY {}
@@ -102,19 +80,12 @@ package Module::Install::Base::FakeAdmin;
 
 my $Fake;
 sub new { $Fake ||= bless(\@_, $_[0]) }
-
 sub AUTOLOAD {}
-
 sub DESTROY {}
 
-# Restore warning handler
-BEGIN {
-	$SIG{__WARN__} = $SIG{__WARN__}->();
-}
-
 1;
 
-=pod
+__END__
 
 =back
 
@@ -124,11 +95,11 @@ L<Module::Install>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
+Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2003, 2004 by Audrey Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
