@@ -1,14 +1,11 @@
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Build.pm $ $Author: ingy $
+# $Revision: #23 $ $Change: 1255 $ $DateTime: 2003/03/05 13:23:32 $ vim: expandtab shiftwidth=4
+
 package Module::Install::Build;
-
+$VERSION = '0.01';
 use strict;
-use Module::Install::Base;
-
-use vars qw{$VERSION $ISCORE @ISA};
-BEGIN {
-	$VERSION = '0.66_02';
-	$ISCORE  = 1;
-	@ISA     = qw{Module::Install::Base};
-}
+use vars qw(@ISA);
+use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
 sub Build { $_[0] }
 
@@ -19,18 +16,18 @@ sub write {
     my %args;
     my $build;
 
-    $args{dist_name}     = $self->name || $self->determine_NAME($self->{args});
-    $args{license}       = $self->license;
-    $args{test_files}    = $self->tests;
-    $args{dist_version}  = $self->version || $self->determine_VERSION($self->{args});
-    $args{dist_abstract} = $self->abstract;
-    $args{dist_author}   = $self->author;
-    $args{sign}          = $self->sign;
-    $args{no_index}      = $self->no_index;
+    $args{dist_name} = $self->name || $self->determine_NAME($self->{args});
+    $args{license} = $self->license;
+    $args{dist_version} = $self->version || $self->determine_VERSION($self->{args});
 
-    foreach my $key (qw(build_requires requires recommends conflicts)) {
-        my $val = eval "\$self->$key" or next;
-        $args{$key} = { map @$_, @$val };
+    if ($] >= 5.005) {
+	$args{ABSTRACT} = $self->abstract;
+	$args{AUTHOR} = $self->author;
+    }
+
+    my $requires = $self->requires;
+    if (defined($requires)) {
+        $args{requires} = { map @$_, @$requires };
     }
 
     %args = map {($_, $args{$_})} grep {defined($args{$_})} keys %args;
@@ -61,6 +58,7 @@ sub ACTION_dist {
 # <DrMath> ingy: then my $build = new MyBuilder( ...parameters... );
 #           $build->write_build_script;
 
+
 1;
 
 __END__
@@ -85,8 +83,8 @@ In your F<Makefile.PL>:
 
 This module is a wrapper around B<Module::Build>.
 
-The C<&Build-E<gt>write> function will pass on keyword/value pair
-functions to C<Module::Build::create_build_script>.
+The C<&Build->write> function will pass on keyword/value pair functions
+to C<Module::Build::create_build_script>.
 
 =head2 VERSION
 
@@ -162,15 +160,14 @@ L<Module::Install>, L<CPAN::MakeMaker>, L<CPAN::MakeMaker-Philosophy>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
+Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
 
 Based on original works by Brian Ingerson E<lt>INGY@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2002, 2003, 2004 by
-Audrey Tang E<lt>autrijus@autrijus.orgE<gt>,
-Brian Ingerson E<lt>ingy@cpan.orgE<gt>
+Copyright 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright (c) 2002. Brian Ingerson. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
